==> haskell-aeson-better-errors-0.9.1.0-77-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-BvfXWbmscHx4ze0XO3eTjU
key: aeson-better-errors-0.9.1.0-BvfXWbmscHx4ze0XO3eTjU
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
abi: b55309c508673cdbe30304a3b369483b
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-BvfXWbmscHx4ze0XO3eTjU
depends:
    base-4.11.1.0 aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD text-1.2.3.0
    bytestring-0.10.8.2 scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W mtl-2.2.2
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-5Oo1Sp1QUM1GMDoxqgB2DX=703c560734a72c2a014a198df0039e3a
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.0-78-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-7OiHqd4LnFJCD2NcbRXeFJ
key: aeson-better-errors-0.9.1.0-7OiHqd4LnFJCD2NcbRXeFJ
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
abi: 7dd18747db3df009150862b052d9d78d
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-7OiHqd4LnFJCD2NcbRXeFJ
depends:
    base-4.11.1.0 aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD text-1.2.3.0
    bytestring-0.10.8.2 scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W mtl-2.2.2
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-9qWiRNFZVktJndCRfB1Mai=107057a2dbf5fda7f784a80ae20f44b9
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
